@@ -86,18 +86,10 @@ impl Opt {
             self.long_shell = true;
         }
 
-        if args.no_ascii {
-            self.no_ascii = true;
-        }
-
         if args.ascii_artists {
             self.ascii_artists = true;
         }
 
-        if args.custom_ascii.is_some() {
-            self.custom_ascii = args.custom_ascii;
-        }
-
         if args.config.is_some() {
             self.config = args.config;
         }
@@ -110,10 +102,6 @@ impl Opt {
             self.show = args.show;
         }
 
-        if args.palette.is_some() {
-            self.palette = args.palette;
-        }
-
         if args.interface.is_some() {
             self.interface = args.interface;
         }
